#
# spec file for package kdiagram
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kdiagram
Version:        2.8.0
Release:        1.11
Summary:        Powerful libraries (KChart, KGantt) for creating business diagrams
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-linguist-devel >= 5.12.0
BuildRequires:  cmake(Qt5PrintSupport) >= 5.12.0
BuildRequires:  cmake(Qt5Svg) >= 5.12.0
BuildRequires:  cmake(Qt5Test) >= 5.12.0
BuildRequires:  cmake(Qt5Widgets) >= 5.12.0

%description
%{summary}

%package -n libKChart2
Summary:        KChart library for kdiagram
Group:          System/Libraries
Recommends:     libkchart-lang = %{version}
Provides:       libkchart = %{version}

%description -n libKChart2
This package contains the KChart libraries from the kdiagram package.

%package -n libKGantt2
Summary:        Gantt chart implementation for kdiagram
Group:          System/Libraries
Recommends:     libkgantt-lang = %{version}
Provides:       libkgantt = %{version}

%description -n libKGantt2
This package contains the KGantt libraries from the kdiagram package.

%lang_package -n libkgantt

%lang_package -n libkchart

%package devel
Summary:        Development package for the KDiagram libraries
Group:          System/Libraries/KDE
Requires:       libKChart2 = %{version}
Requires:       libKGantt2 = %{version}
Requires:       cmake(Qt5Core) >= 5.12.0
Requires:       cmake(Qt5PrintSupport) >= 5.12.0
Requires:       cmake(Qt5Svg) >= 5.12.0
Requires:       cmake(Qt5Widgets) >= 5.12.0

%description devel
Development package for the KDiagram libraries

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
%if %{with lang}
  %find_lang kgantt --with-qt --without-mo
  %find_lang kchart --with-qt --without-mo
%endif

%post -n libKChart2 -p /sbin/ldconfig
%postun -n libKChart2 -p /sbin/ldconfig
%post -n libKGantt2 -p /sbin/ldconfig
%postun -n libKGantt2 -p /sbin/ldconfig

%files -n libKChart2
%license LICENSE.GPL.txt
%{_libdir}/libKChart.so.*

%files -n libKGantt2
%license LICENSE.GPL.txt
%{_libdir}/libKGantt.so.*

%if %{with lang}
%files -n libkchart-lang -f kchart.lang
%license LICENSE.GPL.txt

%files -n libkgantt-lang -f kgantt.lang
%license LICENSE.GPL.txt
%endif

%files devel
%license LICENSE.GPL.txt
%{_includedir}/KChart/
%{_includedir}/kchart_version.h
%{_includedir}/KGantt/
%{_includedir}/kgantt_version.h
%{_libdir}/libKChart.so
%{_libdir}/libKGantt.so
%{_libdir}/qt5/mkspecs/modules/qt_KChart.pri
%{_libdir}/qt5/mkspecs/modules/qt_KGantt.pri
%{_libdir}/cmake/KChart/
%{_libdir}/cmake/KGantt/

%changelog
* Fri Jan 15 2021 wbauer@tmo.at
- Update to 2.8.0
  * KGantt:
    + Fix Bug 430452 - Printing with row labels on multiple pages
    does not work well (kde#430452)
    + Add support for single page printout
    + Add support for printing on multiple pages, both horizontally
    and vertical
    + Make it possible to use a printer friendly palette to allow
    for printing on white paper when using a dark theme
    (kde#426240)
    + Add 'zoom' of datetime header using mouse
* Tue Apr 21 2020 wbauer@tmo.at
- Update to 2.7.0
  * KGantt:
    + Add timeline and a settings dialog to enable user control
    + Let the selectionmodel control the selection of items
    + Fix crash when setGraphicsView() is called
  * KChart:
    + Fix Bug 420180 - Gaps not respected when x-axis is reversed
    (kde#420180)
    + Legend: Add new paint method
    + Give Rulerattributes a ruler pen
    + Don't hardcode default text color but use the palette
    + Fix build issues when qreal == float
- Install license file
* Wed Apr 15 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.6.3
  * KChart: Mark layout as dirty when painting a rect != geometry()
* Sun Mar 29 2020 wbauer@tmo.at
- Update to 2.6.2
  * Reimplement Chart::paint() to fix printing issues
    The previous implementation did not take the headers and
    footers into account when resizing the diagram (kde#405075)
  * Fix painting bar diagrams with horizontal bars
  * Do not reference private headers in KChart convenience header
- Add full Source URL
- Use %%lang_package macro
- Run spec-cleaner
* Thu Apr 19 2018 wbauer@tmo.at
- Update to 2.6.1 bugfix release
  * KChart: Honor Orientation when laying out legend items
  * KGantt: Use old ForwardingProxyModel when setting new
    GraphicsView
  * KGantt: Also remove constraints from children of removed row
  * Replace constraint if data is not identical
  * Fix constraints not always removed
  * Don't leak the stacked plotter
  * Do not access graphics view after it is deleted
  * Avoid crash if leftView() is not a KGanttTreeView
  * Don't leak symbols of private classes
  * Shorten thick pens lines in legend
  * Optimize: do not call potentially detaching QVector::operator()
  * New: optional feature to create API dox QCH files during the
    build
* Wed May 17 2017 fabian@ritter-vogt.de
- Unconditionally Recommend -lang subpackages
* Mon Dec 12 2016 jengelh@inai.de
- RPM group reclassification and summary update
* Tue Nov 22 2016 lbeltrame@kde.org
- Initial package of KDiagram, a charting library
